==> devops-client-java-1.0.3-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineTaskArgumentSchemaBuilder.java <==
package io.alauda.devops.java.client.models;

import io.alauda.devops.java.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1PipelineTaskArgumentSchemaBuilder extends V1alpha1PipelineTaskArgumentSchemaFluentImpl<V1alpha1PipelineTaskArgumentSchemaBuilder> implements VisitableBuilder<V1alpha1PipelineTaskArgumentSchema,V1alpha1PipelineTaskArgumentSchemaBuilder>{

    V1alpha1PipelineTaskArgumentSchemaFluent<?> fluent;
    Boolean validationEnabled;

    public V1alpha1PipelineTaskArgumentSchemaBuilder(){
            this(true);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(Boolean validationEnabled){
            this(new V1alpha1PipelineTaskArgumentSchema(), validationEnabled);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchemaFluent<?> fluent){
            this(fluent, true);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchemaFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1alpha1PipelineTaskArgumentSchema(), validationEnabled);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchemaFluent<?> fluent,V1alpha1PipelineTaskArgumentSchema instance){
            this(fluent, instance, true);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchemaFluent<?> fluent,V1alpha1PipelineTaskArgumentSchema instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withType(instance.getType());

            this.validationEnabled = validationEnabled; 
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchema instance){
            this(instance,true);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchema instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withType(instance.getType());

            this.validationEnabled = validationEnabled; 
    }

    public V1alpha1PipelineTaskArgumentSchema build(){
            V1alpha1PipelineTaskArgumentSchema buildable = new V1alpha1PipelineTaskArgumentSchema();
            buildable.setType(fluent.getType());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1PipelineTaskArgumentSchemaBuilder that = (V1alpha1PipelineTaskArgumentSchemaBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> devops-client-java-1.0.7.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineTaskArgumentSchemaBuilder.java <==
package io.alauda.devops.java.client.models;

import io.alauda.devops.java.client.fluent.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class V1alpha1PipelineTaskArgumentSchemaBuilder extends V1alpha1PipelineTaskArgumentSchemaFluentImpl<V1alpha1PipelineTaskArgumentSchemaBuilder> implements VisitableBuilder<V1alpha1PipelineTaskArgumentSchema,V1alpha1PipelineTaskArgumentSchemaBuilder>{

    V1alpha1PipelineTaskArgumentSchemaFluent<?> fluent;
    Boolean validationEnabled;

    public V1alpha1PipelineTaskArgumentSchemaBuilder(){
            this(true);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(Boolean validationEnabled){
            this(new V1alpha1PipelineTaskArgumentSchema(), validationEnabled);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchemaFluent<?> fluent){
            this(fluent, true);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchemaFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new V1alpha1PipelineTaskArgumentSchema(), validationEnabled);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchemaFluent<?> fluent,V1alpha1PipelineTaskArgumentSchema instance){
            this(fluent, instance, true);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchemaFluent<?> fluent,V1alpha1PipelineTaskArgumentSchema instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withEnum(instance.getEnum());

            fluent.withType(instance.getType());

            this.validationEnabled = validationEnabled; 
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchema instance){
            this(instance,true);
    }
    public V1alpha1PipelineTaskArgumentSchemaBuilder(V1alpha1PipelineTaskArgumentSchema instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withEnum(instance.getEnum());

            this.withType(instance.getType());

            this.validationEnabled = validationEnabled; 
    }

    public V1alpha1PipelineTaskArgumentSchema build(){
            V1alpha1PipelineTaskArgumentSchema buildable = new V1alpha1PipelineTaskArgumentSchema();
            buildable.setEnum(fluent.getEnum());
            buildable.setType(fluent.getType());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1alpha1PipelineTaskArgumentSchemaBuilder that = (V1alpha1PipelineTaskArgumentSchemaBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
